==> gwt-mt-widgets-spring-gwtp-1.11.7-sources.jar: de/knightsoftnet/gwtp/spring/shared/search/_SearchRequestValidatorImpl.java <==
package de.knightsoftnet.gwtp.spring.shared.search;

import de.knightsoftnet.validators.client.impl.AbstractGwtSpecificValidator;
import de.knightsoftnet.validators.client.impl.ConstraintDescriptorImpl;
import de.knightsoftnet.validators.client.impl.Group;
import de.knightsoftnet.validators.client.impl.GroupChain;
import de.knightsoftnet.validators.client.impl.GroupChainGenerator;
import de.knightsoftnet.validators.client.impl.GwtBeanDescriptor;
import de.knightsoftnet.validators.client.impl.GwtBeanDescriptorImpl;
import de.knightsoftnet.validators.client.impl.GwtValidationContext;
import de.knightsoftnet.validators.client.impl.metadata.BeanMetadata;
import de.knightsoftnet.validators.client.impl.metadata.ValidationGroupsMetadata;
import de.knightsoftnet.validators.client.impl.PropertyDescriptorImpl;

import org.hibernate.validator.internal.engine.path.PathImpl;

import java.lang.annotation.Annotation;
import java.lang.IllegalArgumentException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import javax.validation.ConstraintViolation;
import javax.validation.Path.Node;
import javax.validation.ValidationException;

public class _SearchRequestValidatorImpl
    extends AbstractGwtSpecificValidator<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest>
    implements _SearchRequestValidator {
  private static final java.util.List<String> ALL_PROPERTY_NAMES = 
      java.util.Collections.<String>unmodifiableList(
          java.util.Arrays.<String>asList("searchCriterias","class"));
  private final BeanMetadata beanMetadata =
      new BeanMetadata(
          de.knightsoftnet.gwtp.spring.shared.search.SearchRequest.class,
          javax.validation.groups.Default.class);

  private final GwtBeanDescriptor<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanDescriptor = 
      GwtBeanDescriptorImpl.builder(de.knightsoftnet.gwtp.spring.shared.search.SearchRequest.class)
          .setConstrained(false)
          .setBeanMetadata(beanMetadata)
          .build();


  public <T> void validateClassGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
    validateAllNonInheritedProperties(context, object, violations, groups);
  }

  public <T> void expandDefaultAndValidateClassGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validateAllNonInheritedProperties(context, object, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validateAllNonInheritedProperties(context, object, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void expandDefaultAndValidatePropertyGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final String propertyName,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validatePropertyGroups(context, object, propertyName, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validatePropertyGroups(context, object, propertyName, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void expandDefaultAndValidateValueGroups(
      final GwtValidationContext<T> context,
      final Class<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanType,
      final String propertyName,
      final Object value,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validateValueGroups(context, beanType, propertyName, value, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validateValueGroups(context, beanType, propertyName, value, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void validatePropertyGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final String propertyName,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) throws ValidationException {
    switch (propertyName) {
      default:
        if (!ALL_PROPERTY_NAMES.contains(propertyName)) {
          throw new IllegalArgumentException(propertyName + " is not a valid property of "
              + "de.knightsoftnet.gwtp.spring.shared.search.SearchRequest");
        }
        break;
    }
  }

  public <T> void validateValueGroups(
      final GwtValidationContext<T> context,
      final Class<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanType,
      final String propertyName,
      final Object value,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
    switch (propertyName) {
      default:
        if (!ALL_PROPERTY_NAMES.contains(propertyName)) {
          throw new IllegalArgumentException(propertyName + " is not a valid property of "
              + "de.knightsoftnet.gwtp.spring.shared.search.SearchRequest");
        }
        break;
    }
  }

  public BeanMetadata getBeanMetadata() {
    return beanMetadata;
  }

  public GwtBeanDescriptor<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> getConstraints(
      final ValidationGroupsMetadata validationGroupsMetadata) {
    beanDescriptor.setValidationGroupsMetadata(validationGroupsMetadata);
    return beanDescriptor;
  }


  private <T> void validateAllNonInheritedProperties(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
  }


}

==> gwt-mt-widgets-spring-gwtp-1.11.11-sources.jar: de/knightsoftnet/gwtp/spring/shared/search/_SearchRequestValidatorImpl.java <==
package de.knightsoftnet.gwtp.spring.shared.search;

import de.knightsoftnet.validators.client.impl.AbstractGwtSpecificValidator;
import de.knightsoftnet.validators.client.impl.ConstraintDescriptorImpl;
import de.knightsoftnet.validators.client.impl.Group;
import de.knightsoftnet.validators.client.impl.GroupChain;
import de.knightsoftnet.validators.client.impl.GroupChainGenerator;
import de.knightsoftnet.validators.client.impl.GwtBeanDescriptor;
import de.knightsoftnet.validators.client.impl.GwtBeanDescriptorImpl;
import de.knightsoftnet.validators.client.impl.GwtValidationContext;
import de.knightsoftnet.validators.client.impl.metadata.BeanMetadata;
import de.knightsoftnet.validators.client.impl.metadata.ValidationGroupsMetadata;
import de.knightsoftnet.validators.client.impl.PropertyDescriptorImpl;

import org.hibernate.validator.internal.engine.path.PathImpl;

import java.lang.annotation.Annotation;
import java.lang.IllegalArgumentException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import javax.validation.ConstraintViolation;
import javax.validation.Path.Node;
import javax.validation.ValidationException;

public class _SearchRequestValidatorImpl
    extends AbstractGwtSpecificValidator<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest>
    implements _SearchRequestValidator {
  private static final java.util.List<String> ALL_PROPERTY_NAMES = 
      java.util.Collections.<String>unmodifiableList(
          java.util.Arrays.<String>asList("searchCriterias","class"));
  private final BeanMetadata beanMetadata =
      new BeanMetadata(
          de.knightsoftnet.gwtp.spring.shared.search.SearchRequest.class,
          javax.validation.groups.Default.class);

  private final GwtBeanDescriptor<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanDescriptor = 
      (GwtBeanDescriptorImpl) GwtBeanDescriptorImpl.builder(de.knightsoftnet.gwtp.spring.shared.search.SearchRequest.class)
          .setConstrained(false)
          .setBeanMetadata(beanMetadata)
          .build();


  public <T> void validateClassGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
    validateAllNonInheritedProperties(context, object, violations, groups);
  }

  public <T> void expandDefaultAndValidateClassGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validateAllNonInheritedProperties(context, object, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validateAllNonInheritedProperties(context, object, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void expandDefaultAndValidatePropertyGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final String propertyName,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validatePropertyGroups(context, object, propertyName, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validatePropertyGroups(context, object, propertyName, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void expandDefaultAndValidateValueGroups(
      final GwtValidationContext<T> context,
      final Class<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanType,
      final String propertyName,
      final Object value,
      final Set<ConstraintViolation<T>> violations,
      final Group... groups) {
    final ArrayList<Class<?>> justGroups = new ArrayList<>();
    for (Group g : groups) {
      if (!g.isDefaultGroup() || !getBeanMetadata().defaultGroupSequenceIsRedefined()) {
        justGroups.add(g.getGroup());
      }
    }
    final Class<?>[] justGroupsArray = justGroups.toArray(new Class<?>[justGroups.size()]);
    validateValueGroups(context, beanType, propertyName, value, violations, justGroupsArray);
    if (getBeanMetadata().defaultGroupSequenceIsRedefined()) {
      for (Class<?> g : beanMetadata.getDefaultGroupSequence()) {
        int numberOfViolations = violations.size();
        validateValueGroups(context, beanType, propertyName, value, violations, g);
        if (violations.size() > numberOfViolations) {
          break;
        }
      }
    }
  }

  public <T> void validatePropertyGroups(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final String propertyName,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) throws ValidationException {
    switch (propertyName) {
      default:
        if (!ALL_PROPERTY_NAMES.contains(propertyName)) {
          throw new IllegalArgumentException(propertyName + " is not a valid property of "
              + "de.knightsoftnet.gwtp.spring.shared.search.SearchRequest");
        }
        break;
    }
  }

  public <T> void validateValueGroups(
      final GwtValidationContext<T> context,
      final Class<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> beanType,
      final String propertyName,
      final Object value,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
    switch (propertyName) {
      default:
        if (!ALL_PROPERTY_NAMES.contains(propertyName)) {
          throw new IllegalArgumentException(propertyName + " is not a valid property of "
              + "de.knightsoftnet.gwtp.spring.shared.search.SearchRequest");
        }
        break;
    }
  }

  public BeanMetadata getBeanMetadata() {
    return beanMetadata;
  }

  public GwtBeanDescriptor<de.knightsoftnet.gwtp.spring.shared.search.SearchRequest> getConstraints(
      final ValidationGroupsMetadata validationGroupsMetadata) {
    beanDescriptor.setValidationGroupsMetadata(validationGroupsMetadata);
    return beanDescriptor;
  }


  private <T> void validateAllNonInheritedProperties(
      final GwtValidationContext<T> context,
      final de.knightsoftnet.gwtp.spring.shared.search.SearchRequest object,
      final Set<ConstraintViolation<T>> violations,
      final Class<?>... groups) {
  }


}
